@@ -1,3 +1,3 @@
 from .orm import ModelBase, BaseColumns, Testable
 from .core import utcnow
-from . import postgres
+from . import postgres, sqlite
